==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/util/XMLJ__24XMLJShutdownHook.h <==
// class gnu.xml.libxmlj.util.XMLJ$XMLJShutdownHook

// class file dependencies
// @dep_class da76bc4e07f2bd57 gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook_H_
#define _JC_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_refs	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_nonrefs	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$refs	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$refs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$nonrefs	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object;

typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vmethods	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtable	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtable;
typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtype	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object *);

// Virtual methods
extern void _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vmethods	gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook;
};

// Vtype
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$refs {
    _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_refs	gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_nonrefs	gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object {
	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtype	*vtype;
	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtype _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$class_object;

#endif	/* _JC_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/util/XMLJ__24XMLJShutdownHook.h <==
// class gnu.xml.libxmlj.util.XMLJ$XMLJShutdownHook

// class file dependencies
// @dep_class da76bc4e07f2bd57 gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook_H_
#define _JC_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_refs	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_nonrefs	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$refs	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$refs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$nonrefs	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object;

typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vmethods	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtable	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtable;
typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtype	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vmethods	gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook;
};

// Vtype
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$refs {
    _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_refs	gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$sub_nonrefs	gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$object {
	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtype	*vtype;
	_jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$vtype _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook$class_object;

#endif	/* _JC_gnu_xml_libxmlj_util_XMLJ__24XMLJShutdownHook_H_ */
